@@ -6,9 +6,6 @@ class WinkSprinkler(WinkBinarySwitch):
     Represents a Wink Sprinkler.
     """
 
-    def __init__(self, device_state_as_json, api_interface):
-        super(WinkSprinkler, self).__init__(device_state_as_json, api_interface)
-
     def state(self):
         return self._last_reading.get('powered', False)
 
